@@ -1,14 +1,15 @@
 #!/usr/bin/perl
 
-# $Date: 2005/01/18 21:41:14 $
-# $Revision: 1.2.2.4 $
+#
+# $Id: sniffer.pl,v 1.2.2.5 2005/05/22 19:07:56 gomor Exp $
+#
 
 use strict;
 use warnings;
 
 use Getopt::Std;
 my %opts;
-getopts('d:f:v347khp', \%opts);
+getopts('d:f:v347khpA', \%opts);
 
 die "Usage: sniffer.pl [-f filter] [-d device] [-v] [-3] [-4] [-7] [-p]\n".
     " -d:   device to sniff on\n".
@@ -19,6 +20,7 @@ die "Usage: sniffer.pl [-f filter] [-d device] [-v] [-3] [-4] [-7] [-p]\n".
     " -v:   be verbose\n".
     " -k:   keep captured savefile\n".
     " -p:   use promiscuous mode\n".
+    " -A:   print layer 7 as ASCII text\n".
     ""
    if $opts{h};
 
@@ -43,7 +45,15 @@ while (1) {
          if ($opts{3} && $dump->nextFrame->l3);
       print($dump->nextFrame->l4->print, "\n")
          if ($opts{4} && $dump->nextFrame->l4);
-      print($dump->nextFrame->l7->print, "\n")
-         if ($opts{7} && $dump->nextFrame->l7);
+      if ($opts{7} && $dump->nextFrame->l7) {
+         if ($opts{A}) {
+            my $str = $dump->nextFrame->l7->data;
+            $str =~ s/[^[:print:]]//g;
+            print $str, "\n";
+         }
+         else {
+            print($dump->nextFrame->l7->print, "\n");
+         }
+      }
    }
 }
